@@ -845,6 +845,75 @@ impl_GetDefaultAttributeSet (DBusConnection * bus, DBusMessage * message,
   return reply;
 }
 
+static DBusMessage *
+impl_ScrollSubstringTo (DBusConnection * bus,
+                        DBusMessage * message, void *user_data)
+{
+  AtkText *text = (AtkText *) user_data;
+  dbus_int32_t startOffset, endOffset;
+  dbus_uint32_t type;
+  dbus_bool_t ret;
+  DBusMessage *reply = NULL;
+
+  g_return_val_if_fail (ATK_IS_TEXT (user_data),
+                        droute_not_yet_handled_error (message));
+
+  if (!dbus_message_get_args
+       (message, NULL, DBUS_TYPE_INT32, &startOffset,
+                       DBUS_TYPE_INT32, &endOffset,
+                       DBUS_TYPE_UINT32, &type,
+                       DBUS_TYPE_INVALID))
+    {
+      return droute_invalid_arguments_error (message);
+    }
+
+  ret = atk_text_scroll_substring_to (text, startOffset, endOffset, type);
+
+  reply = dbus_message_new_method_return (message);
+  if (reply)
+    {
+      dbus_message_append_args (reply, DBUS_TYPE_BOOLEAN, &ret,
+                                DBUS_TYPE_INVALID);
+    }
+  return reply;
+}
+
+static DBusMessage *
+impl_ScrollSubstringToPoint (DBusConnection * bus,
+                             DBusMessage * message, void *user_data)
+{
+  AtkText *text = (AtkText *) user_data;
+  dbus_int32_t startOffset, endOffset;
+  dbus_uint32_t type;
+  dbus_int32_t x, y;
+  dbus_bool_t ret;
+  DBusMessage *reply = NULL;
+
+  g_return_val_if_fail (ATK_IS_TEXT (user_data),
+                        droute_not_yet_handled_error (message));
+
+  if (!dbus_message_get_args
+       (message, NULL, DBUS_TYPE_INT32, &startOffset,
+                       DBUS_TYPE_INT32, &endOffset,
+                       DBUS_TYPE_UINT32, &type,
+                       DBUS_TYPE_INT32, &x,
+                       DBUS_TYPE_INT32, &y,
+                       DBUS_TYPE_INVALID))
+    {
+      return droute_invalid_arguments_error (message);
+    }
+
+  ret = atk_text_scroll_substring_to_point (text, startOffset, endOffset, type, x, y);
+
+  reply = dbus_message_new_method_return (message);
+  if (reply)
+    {
+      dbus_message_append_args (reply, DBUS_TYPE_BOOLEAN, &ret,
+                                DBUS_TYPE_INVALID);
+    }
+  return reply;
+}
+
 static DRouteMethod methods[] = {
   {impl_GetText, "GetText"},
   {impl_SetCaretOffset, "SetCaretOffset"},
@@ -867,6 +936,8 @@ static DRouteMethod methods[] = {
   {impl_GetBoundedRanges, "GetBoundedRanges"},
   {impl_GetAttributeRun, "GetAttributeRun"},
   {impl_GetDefaultAttributeSet, "GetDefaultAttributeSet"},
+  {impl_ScrollSubstringTo, "ScrollSubstringTo"},
+  {impl_ScrollSubstringToPoint, "ScrollSubstringToPoint"},
   {NULL, NULL}
 };
 
